#
# spec file for package ghc-lua
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name lua
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.3.3
Release:        1.1
Summary:        Lua, an embeddable scripting language
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
This package provides bindings and types to bridge Haskell and
<https://www.lua.org/ Lua>.

The full Lua interpreter version 5.4.7 is included. Alternatively, a
system-wide Lua installation can be linked instead.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Aug 31 2024 Peter Simons <psimons@suse.com>
- Update lua to version 2.3.3.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/lua-2.3.3/src/CHANGELOG.md
* Fri Jan 19 2024 Peter Simons <psimons@suse.com>
- Update lua to version 2.3.2.
  [#]# lua-2.3.2
  Release pending.
  - Update to Lua 5.4.6.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update lua to version 2.3.1.
  [#]# lua-2.3.1
  Released 2023-03-17.
  - New module *Lua.Debug*: the module provides bindings to a
    subset of functions of the Lua debug interface. Currently the
    module only binds `lua_getupvalue` and `lua_setupvalue`.
  [#]# lua-2.3.0
  Released 2023-03-13.
  - New function `hslua_setwarnf`: The function allows to set a
    C function as a hook that is called on all complete warning
    messages. It is intended as a simple way to set a custom
    warning function.
  - Export version and copyright info from Lua.Constants: the
    following patterns are made available, with content identical
    to that of the respective C functions: `LUA_VERSION`,
    `LUA_RELEASE`, and `LUA_COPYRIGHT`.
  - Added a new flag `cross-compile`. When enabled, the code is
    setup in a way that allows cross-compilation of the package,
    but some of the string constants will be hard-coded and may
    not match the Lua version against which the library is
    compiled.
  - `Type` is now an instance of `Read`.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Jun 19 2022 Peter Simons <psimons@suse.com>
- Update lua to version 2.2.1.
  [#]# lua-2.2.1
  Released 2022-06-19.
  - Make string-peeking independent of the current foreign
    encoding: always use char8 encoding to retrieve values of
    `LUA_PRELOAD_TABLE` and `LUA_LOADED_TABLE`.
* Sat Feb 19 2022 Peter Simons <psimons@suse.com>
- Update lua to version 2.2.0.
  [#]# lua-2.2.0
  Released 2022-02-19.
  - Update to Lua 5.4, include Lua 5.4.4 by default.
  - Removed `hardcode-reg-keys` flag: this is no longer required
    for Lua 5.4.
  - Support arbitrary number of uservalues: Lua 5.4 allows an
    arbitrary number of uservalues to be associated with userdata
    objects. The functions `lua_newuserdata`, `lua_getuservalue`,
    and `lua_setuservalue` are replaced with the new functions
    `lua_newuserdatauv`, `lua_getiuservalue`, and
    `lua_setiuservalue`, respectively.
    The function `hslua_newhsuserdata` is renamed to
    `hslua_newhsuserdatauv` and takes the number of associated
    uservalues as an additional argument.
  - Support for the new warnings system: export binding to
    `lua_warning`.
  - The function `lua_gc` now takes three data arguments of type
    CInt. This is a workaround for the fact that the C function
    has become variadic.
  - The new patterns `LUA_GCGEN` and `LUA_GCINC` are usable with
    `lua_gc` to switch to generational and incremental garbage
    collection, respectively.
* Sat Jan 29 2022 Peter Simons <psimons@suse.com>
- Update lua to version 2.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/lua-2.1.0/src/CHANGELOG.md
* Thu Nov  4 2021 psimons@suse.com
- Update lua to version 2.0.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/lua-2.0.1/src/CHANGELOG.md
* Mon Nov  1 2021 psimons@suse.com
- Add lua at version 2.0.0.1.
